//{{NO_DEPENDENCIES}}
// Microsoft Developer Studio generated include file.
// Used by w32_console.rc
//
#define IDR_MENU                        102
#define IDR_ACCEL                       106
#define IDM_COPY                        40002
#define IDM_PASTE                       40003
#define IDM_FONT                        40004
#define IDM_ABOUT                       40005
#define IDM_MANUAL                      40006
#define IDM_EXIT                        40007
#define IDM_INDEX                       40009
#define IDM_FLUSH                       40011
#define IDM_INTERRUPT                   40012
#define IDM_BUFFERING                   40013
#define IDM_SHOW_CONSOLE                40015
#define IDM_CONSULT                     40016
#define IDM_CHDIR                       40018
#define IDM_FILE_NAME                   40019
#define IDM_WEB                         40020

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NO_MFC                     1
#define _APS_NEXT_RESOURCE_VALUE        111
#define _APS_NEXT_COMMAND_VALUE         40021
#define _APS_NEXT_CONTROL_VALUE         1008
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif
